EditorImageResult class

The editor's result.

Constructors

EditorImageResult(int imgWidth, int imgHeight, File newFile)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imgHeight → int
image height
final
imgWidth → int
image width
final
newFile → File
new file after edit
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited