ImageEditorState class

Inheritance
Mixed-in types

Constructors

ImageEditorState()

Properties

bottomBarHeight → double
no setter
canvasHeight → double
Edit area height.
no setter
canvasSetter ↔ StateSetter
getter/setter pairinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controlBtnSpacing → Widget
Operation panel button's horizontal space.
no setter
flipValue ↔ double
canvas flip value
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
headerHeight → double
no setter
lastDrawStyle → DrawStyle
no setterinherited
mosaicWidth ↔ double
mosaic pixel's width
getter/setter pairinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
painterController ↔ SignatureController
painter controller
getter/setter pairinherited
pathRecord → List<Widget>
Canvas layer for each draw action action.
finalinherited
pColor ↔ Color
painter color
getter/setter pairinherited
pStrockWidth ↔ double
painter stroke width.
getter/setter pairinherited
rotateValue ↔ int
canvas rotate value
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenHeight → double
no setterinherited
screenshotController → ScreenshotController
finalinherited
screenWidth → double
no setterinherited
textModels → List<FloatTextModel>
finalinherited
textSetter ↔ StateSetter
getter/setter pairinherited
widget → ImageEditor
The current configuration.
no setterinherited
windowBottomBarHeight → double
no setterinherited
windowSize → Size
no setterinherited
windowStatusBarHeight → double
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addText(FloatTextModel model) → void
inherited
backWidget({VoidCallback? onPressed}) → Widget
go back widget
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildTextCanvas() → Widget
inherited
changePainterColor(Color color) → void
change painter's color
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decodeImg() → Future<Image?>
deleteTextWidget(FloatTextModel target) → void
delete a text from canvas
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant ImageEditor oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
doneButtonWidget({VoidCallback? onPressed}) → Widget
action done widget
inherited
flipCanvas() → void
flip canvas
inherited
getOperateTypeRes(OperateType type, {required bool choosen}) → Widget
operation button in control bar
inherited
ignoreWidgetByType(OperateType type, Widget child) → Widget
Ignore pointer evenet by OperateType
inherited
initPainter() → void
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
refreshTextCanvas() → void
inherited
resetCanvasPlate() → void
reset canvas
inherited
resetWidget({VoidCallback? onTap}) → Widget
reset button
inherited
rotateCanvasPlate() → void
routate canvas
inherited
saveImage() → void
Save the edited-image to widget.savePath or getTemporaryDirectory().
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
switchPainterMode(DrawStyle style) → void
switch painter's style
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
toTextEditorPage() → void
inherited
undo() → void
undo last drawing.
inherited
unDoWidget({VoidCallback? onPressed}) → Widget
undo action
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → ImageEditorState?