FloatTextModel class

Text widget model, for help to move text-widget.

Inheritance

Constructors

FloatTextModel({required String text, TextStyle? style, required double top, required double left, bool isSelected = false})

Properties

floatSize → Size?
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isSelected ↔ bool
getter/setter pair
left ↔ double
the left of position
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size?
widget's size
getter/setter pair
style ↔ TextStyle?
getter/setter pair
text ↔ String
getter/setter pair
top ↔ double
the top of position
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited