DefaultTextConfigModel class

Inheritance

Constructors

DefaultTextConfigModel()

Properties

cursorColor → Color
input field's cursor color.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
initSize → double
initial size
no setteroverride
isLegal → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliderBottomLimit → double
slider bottom limit
no setteroverride
sliderUpLimit → double
slider up limit
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited