ImageEditorDelegate class abstract

For delegate ImageEditor's ui style.

Implementers

Constructors

ImageEditorDelegate()

Properties

boldTagWidget → Widget
To control the text style of bold.
no setter
brushColors → List<Color>
Brush colors
no setter
hashCode → int
The hash code for this object.
no setterinherited
resetWidget → Widget
Reset widget
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliderLeftWidget → Widget
Slider's tag
no setter
sliderRightWidget → Widget
Slider's tag
no setter
textColors → List<Color>
Text Colors
no setter
textConfigModel → TextConfigModel
Text config model
no setter
textSelectedBorder → Border
Text selected border
no setter

Methods

addTextWidget(double limitSize, OperateType type, {required bool choosen}) → Widget
Add text widget
backBtnWidget(double limitSize) → Widget
Back button on appbar
brushWidget(double limitSize, OperateType type, {required bool choosen}) → Widget
Brush widget
buildBackWidget() → Widget
buildDoneWidget() → Widget
buildOperateWidget(OperateType type, {required bool choosen}) → Widget
buildUndoWidget() → Widget
doneWidget(BoxConstraints constraints) → Widget
Done widget
flipWidget(double limitSize, OperateType type, {required bool choosen}) → Widget
Flip widget
mosaicWidget(double limitSize, OperateType type, {required bool choosen}) → Widget
Mosaic widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateWidget(double limitSize, OperateType type, {required bool choosen}) → Widget
Rotate widget
sliderThemeData(BuildContext context) → SliderThemeData
Slider's theme data
toString() → String
A string representation of this object.
inherited
undoWidget(double limitSize) → Widget
Undo widget

Operators

operator ==(Object other) → bool
The equality operator.
inherited