TextConfigModel class abstract

This model for TextEditorPage to initial text style.

Implementers

Constructors

TextConfigModel()

Properties

cursorColor → Color
input field's cursor color.
no setter
hashCode → int
The hash code for this object.
no setterinherited
initSize → double
initial size
no setter
isLegal → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliderBottomLimit → double
slider bottom limit
no setter
sliderUpLimit → double
slider up limit
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited