CustomRoundSliderOverlayShape class

Inheritance

Constructors

CustomRoundSliderOverlayShape({double overlayRadius = 0.0})
Create a slider thumb overlay that draws a circle.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
overlayRadius → double
The preferred radius of the round thumb shape when enabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPreferredSize(bool isEnabled, bool isDiscrete) → Size
Returns the preferred size of the shape, based on the given conditions.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset center, {required Animation<double> activationAnimation, required Animation<double> enableAnimation, required bool isDiscrete, required TextPainter labelPainter, required RenderBox parentBox, required SliderThemeData sliderTheme, required TextDirection textDirection, required double value, required double textScaleFactor, required Size sizeWithOverflow}) → void
Paints the shape, taking into account the state passed to it.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited